/* Check in a number of files (paths in stdin, one path per line)
   if the indicators for "destaq view" are present in the correct
   order, i.e. in pairs of start and stop.
   Signal pathname and line number if not.
 */

#include <stdio.h>
#include <string.h>

char pathname[256];

void CheckThisFile (char *path);

int main (int argc, char **argv)
{
   while (fgets(pathname, sizeof pathname, stdin) != NULL)
   {
      char *e = strchr(pathname, '\n');
      if (e) *e = '\0';

      CheckThisFile(pathname);
   }
   return 0;
}

char linebuf[4192];
void CheckThisFile (char *path)
{
   enum seen
   {
      SEEN_NONE ,
      SEEN_START,
      SEEN_STOP
   };
   enum seen seen_prev = SEEN_NONE;
   enum seen seen_now  = SEEN_NONE;
   FILE *fp;
   long linecnt = 0;
   long strtcnt = 0;

   if ((fp = fopen(path, "r")) == NULL)
   {
      fprintf(stderr, "Can't open file %s\n", path);
   }

   while (fgets(linebuf, sizeof linebuf, fp) != NULL)
   {
      linecnt++;
      seen_now = SEEN_NONE;
      if ((strstr(linebuf, "<!-- Start Destaque Rudhar.com -->")) != NULL)
      {
         seen_now = SEEN_START;
         strtcnt = linecnt;
      } else
      if ((strstr(linebuf, "<!-- Stop Destaque Rudhar.com -->")) != NULL)
         seen_now = SEEN_STOP;

      if (seen_now == SEEN_START && seen_prev != SEEN_NONE)
      {
         fprintf(stdout, "Incorrect Start at line %5ld in file %s\n",
            linecnt, path);
         /* Interpret as a Stop */
         seen_now = SEEN_STOP;
      } else
      if (seen_now == SEEN_STOP && seen_prev != SEEN_START)
      {
         fprintf(stdout, "Incorrect Stop  at line %5ld in file %s\n",
            linecnt, path);
      }

      if (seen_now == SEEN_START)
         seen_prev = SEEN_START;
      if (seen_now == SEEN_STOP)
         seen_prev = SEEN_NONE;
   }
   fclose(fp);

   if (seen_prev == SEEN_START)
   {
      fprintf(stdout, "Unclosed  Start at line %5ld in file %s\n",
         strtcnt, path);
   }
}
